==> gradle-6.5-src.zip: gradle-6.5/subprojects/plugin-use/plugin-use.gradle.kts <==
import org.gradle.gradlebuild.testing.integrationtests.cleanup.WhenNotEmpty

/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
plugins {
    gradlebuild.distribution.`plugins-api-java`
}

dependencies {
    implementation(project(":baseServices"))
    implementation(project(":logging"))
    implementation(project(":messaging"))
    implementation(project(":fileCollections"))
    implementation(project(":coreApi"))
    implementation(project(":core"))
    implementation(project(":dependencyManagement"))

    runtimeOnly(project(":resourcesHttp"))

    implementation(library("groovy"))
    implementation(library("guava"))

    testImplementation(testFixtures(project(":resourcesHttp")))

    integTestImplementation(project(":baseServicesGroovy"))
    integTestImplementation(library("jetbrains_annotations"))

    integTestRuntimeOnly(project(":plugins"))
    integTestRuntimeOnly(project(":pluginDevelopment"))
    integTestRuntimeOnly(project(":testKit"))
    integTestRuntimeOnly(project(":toolingApiBuilders"))
    integTestRuntimeOnly(project(":runtimeApiInfo"))
    integTestRuntimeOnly(project(":testingJunitPlatform"))
    integTestRuntimeOnly(project(":apiMetadata"))
    integTestRuntimeOnly(project(":kotlinDsl"))
    integTestRuntimeOnly(project(":kotlinDslProviderPlugins"))
}

testFilesCleanup {
    policy.set(WhenNotEmpty.REPORT)
}

==> gradle-6.6.1-src.zip: gradle-6.6.1/subprojects/plugin-use/plugin-use.gradle.kts <==
import org.gradle.gradlebuild.testing.integrationtests.cleanup.WhenNotEmpty

/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
plugins {
    gradlebuild.distribution.`api-java`
}

dependencies {
    implementation(project(":baseServices"))
    implementation(project(":logging"))
    implementation(project(":messaging"))
    implementation(project(":fileCollections"))
    implementation(project(":coreApi"))
    implementation(project(":core"))
    implementation(project(":dependencyManagement"))
    implementation(project(":buildOption"))

    implementation(library("groovy"))
    implementation(library("guava"))

    testImplementation(testFixtures(project(":resourcesHttp")))

    integTestImplementation(project(":baseServicesGroovy"))
    integTestImplementation(library("jetbrains_annotations"))

    integTestDistributionRuntimeOnly(project(":distributionsBasics")) {
        because("Requires test-kit: 'java-gradle-plugin' is used in integration tests which always adds the test-kit dependency.")
    }
}

testFilesCleanup {
    policy.set(WhenNotEmpty.REPORT)
}
